@@ -1,5 +1,5 @@
 package Treex::Block::Read::BaseTextReader;
-$Treex::Block::Read::BaseTextReader::VERSION = '2.20150928';
+$Treex::Block::Read::BaseTextReader::VERSION = '2.20151210';
 use Moose;
 use Treex::Core::Common;
 extends 'Treex::Block::Read::BaseReader';
@@ -21,6 +21,9 @@ sub BUILD {
     if ( $self->lines_per_doc ) {
         $self->set_is_one_doc_per_file(0);
     }
+    if ($self->encoding ne 'utf8'){
+        $self->from->set_encoding($self->encoding);
+    }
     return;
 }
 
@@ -60,7 +63,7 @@ Treex::Block::Read::BaseTextReader - abstract ancestor for document readers
 
 =head1 VERSION
 
-version 2.20150928
+version 2.20151210
 
 =head1 DESCRIPTION
 
