@@ -1,5 +1,5 @@
 package Treex::Core::Node::A;
-$Treex::Core::Node::A::VERSION = '2.20150928';
+$Treex::Core::Node::A::VERSION = '2.20151210';
 use namespace::autoclean;
 use Moose;
 use Treex::Core::Common;
@@ -212,7 +212,8 @@ sub copy_attributes
     # We should copy all attributes that the node has but it is not easy to figure out which these are.
     # TODO: As a workaround, we list the attributes here directly.
     foreach my $attribute (
-        'form', 'lemma', 'tag', 'no_space_after', 'ord', 'deprel', 'afun', 'is_member', 'is_parenthesis_root',
+        'form', 'lemma', 'tag', 'no_space_after', 'translit', 'gloss',
+        'ord', 'deprel', 'afun', 'is_member', 'is_parenthesis_root',
         'conll/deprel', 'conll/cpos', 'conll/pos', 'conll/feat', 'is_shared_modifier', 'morphcat',
         )
     {
@@ -449,7 +450,7 @@ Treex::Core::Node::A
 
 =head1 VERSION
 
-version 2.20150928
+version 2.20151210
 
 =head1 DESCRIPTION
 
